betty.privatizer module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.privatizer module

Provide an API to determine if information should be kept private.

class betty.privatizer.Privatizer

  Bases: `object`

  Privatize resources.

  __init__(lifetime_threshold: int, *, localizer: Localizer)
  has_expired(subject: Person | Event | Date | None, generations_ago: int = 0) → bool

    Check if a subject of the given generation has expired.

  privatize(subject: HasPrivacy) → None

    Privatize a resource.